@@ -23,7 +23,7 @@ this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 Place, Suite 330, Boston, MA 02111-1307 USA.
 """
 
-__version__ = "1.4.4"
+__version__ = "1.6.0"
 
 __all__ = [
 
@@ -63,24 +63,22 @@ __all__ = [
     "manifest",
     "methodpool",
     "cache",
+    "providers",
  ]
 
 whitespace = '\t\n\x0b\x0c\r '
 lowercase = 'abcdefghijklmnopqrstuvwxyz'
 
-import sys, os, types, re, string
+import sys, os, types, re, string, bb
+from bb import msg
 
 #projectdir = os.path.dirname(os.path.dirname(os.path.abspath(sys.argv[0])))
 projectdir = os.getcwd()
 
-debug_level = 0
-
 if "BBDEBUG" in os.environ:
     level = int(os.environ["BBDEBUG"])
     if level:
-        debug_level = level
-    else:
-        debug_level = 0
+        bb.msg.set_debug_level(level)
 
 class VarExpandError(Exception):
     pass
@@ -99,22 +97,17 @@ class MalformedUrl(Exception):
 #######################################################################
 #######################################################################
 
-debug_prepend = ''
-
-
 def debug(lvl, *args):
-    if debug_level >= lvl:
-        print debug_prepend + 'DEBUG:', ''.join(args)
+    bb.msg.std_debug(lvl, ''.join(args))
 
 def note(*args):
-    print debug_prepend + 'NOTE:', ''.join(args)
+    bb.msg.std_note(''.join(args))
 
 def error(*args):
-    print debug_prepend + 'ERROR:', ''.join(args)
+    bb.msg.std_error(''.join(args))
 
 def fatal(*args):
-    print debug_prepend + 'ERROR:', ''.join(args)
-    sys.exit(1)
+    bb.msg.std_fatal(''.join(args))
 
 
 #######################################################################
